@@ -1,6 +1,7 @@
 import json
 import os
 import shutil
+import uuid
 from pathlib import Path
 
 __all__ = [
@@ -29,6 +30,11 @@ def from_int(x: Any) -> int:
     return x
 
 
+def from_dict(x: Any) -> Dict[str, Any]:
+    assert isinstance(x, dict)
+    return x
+
+
 def from_bool(x: Any) -> bool:
     assert isinstance(x, bool)
     return x
@@ -90,6 +96,7 @@ class Parameter:
     max_items: Optional[Any]
     unique_items: Optional[Any]
     items: Optional[Any]
+    schema: Optional[Any]
     __data_types = {
         "integer": "int",
         "string": "str",
@@ -112,9 +119,10 @@ class Parameter:
         max_items = from_union([from_int, from_str, from_none], obj.get("maxItems"))
         unique_items = from_union([from_int, from_str, from_none], obj.get("uniqueItems"))
         items = from_union([from_int, from_str, from_none], obj.get("items"))
+        schema = from_union([from_dict, from_none], obj.get("schema"))
         return Parameter(name, parameter_in, required, parameter_type, enum,
                          default, minimum, maximum, description, min_items,
-                         max_items, unique_items, items)
+                         max_items, unique_items, items, schema)
 
     def synth(self):
         return getattr(self, self.parameter_in)()
@@ -140,9 +148,28 @@ class Parameter:
         return code, path_params
 
     def body(self):
-        code = CustomString('payload: dict = Body(None)', 'body_param')
-        payload = CustomString('"body": json.dumps(payload)', 'dict_body')
-        return code, payload
+        if not self.schema:
+            code = CustomString('payload: dict = Body(None)', 'body_param')
+            payload = CustomString('"body": json.dumps(payload)', 'dict_body')
+            model = None
+        else:
+            if self.schema.get("type") != "object":
+                raise ValueError("Only object type is supported for body")
+            _model_name = f"{self.name.capitalize()}{uuid.uuid4().hex}"
+            code = CustomString(f'payload: {_model_name}', 'body_param')
+            payload = CustomString('"body": json.dumps(payload.dict())', 'dict_body')
+            model = self.__build_model(_model_name)
+        return (code, model), payload
+
+    def __build_model(self, model_name):
+        _model = f"class {model_name}(BaseModel):\n"
+        properties = self.schema.get("properties")
+        for _property in properties:
+            _data_type = self.__data_types.get(properties[_property].get("type"), "str")
+            _data_type = f"Optional[{_data_type}] = None" if _property not in self.schema.get("required",
+                                                                                              []) else _data_type
+            _model += f'\t{_property}: {_data_type}\n'
+        return _model
 
 
 def parameter_from_dict(s: Any) -> Parameter:
@@ -163,20 +190,24 @@ class EndpointConfiguration:
         }
 
     def synth(self):
-        self.build_params()
-        params, event_code = self.build_params()
-        code = f'''@router.{self.__method.lower()}("{self.__path}")\nasync def {self.__name}({params}):\n\t{event_code}\n\treturn get_body({self.__handler}(event, None))\n\n'''
+        params, event_code, model = self.build_params()
+        code = f'''{model}\n\n@router.{self.__method.lower()}("{self.__path}")\nasync def {self.__name}(response: Response, {params}):\n\t{event_code}\n\tres = {self.__handler}(event, None)\n\tresponse.status_code = get_status_code(res)\n\treturn get_body(res)\n\n'''
         return code
 
     def build_params(self):
         params = {}
         params_code = {}
+        model = None
         for param in self.__parameters:
             parameter_instance = parameter_from_dict(param)
             result = parameter_instance.synth()
             if not result:
                 continue
             code, d = result
+            try:
+                code, model = code
+            except TypeError:
+                pass
             if parameter_instance.parameter_in not in params:
                 params.setdefault(parameter_instance.parameter_in, code)
                 params_code.setdefault(parameter_instance.parameter_in, d)
@@ -206,7 +237,7 @@ class EndpointConfiguration:
                             query_string_parameters +
                             path_parameters +
                             CustomString(event_dict.get('body'))) + "}")
-        return parameters_result, event_result
+        return parameters_result, event_result, model
 
 
 def read_swagger_template(path):
@@ -240,7 +271,7 @@ def process_api_paths(*, lambda_configuration, handler):
 
 
 def read_all_lambdas(*, lambdas_path, swagger_template):
-    all_imports = 'from fastapi import APIRouter\nfrom fastapi import Body, Header, Query\nfrom core_api.utils import get_body\nimport json\n'
+    all_imports = 'from fastapi import APIRouter\nfrom fastapi import Body, Header, Query, Response\nfrom core_api.utils import get_body, get_status_code\nimport json\nfrom pydantic import BaseModel\nfrom typing import Optional\n'
     all_endpoints = 'router = APIRouter()\n\n'
 
     for name in os.listdir(lambdas_path):
@@ -277,10 +308,27 @@ def build_and_run():
 from fastapi import FastAPI
 from mangum import Mangum
 from src.api_local.router import router
+from fastapi.middleware.cors import CORSMiddleware
+from dotenv import load_dotenv
+import os
+
+
+load_dotenv()
+
+env = os.getenv('ENVIRONMENT', None)
+
 
 app = FastAPI(title='Test API',
               description='API ')
-app.include_router(router, prefix="/v1")
+
+app.add_middleware(
+    CORSMiddleware,
+    allow_origins=["*"],
+    allow_methods=["*"],
+    allow_headers=["*"],
+)
+
+app.include_router(router, prefix=f"/{env.lower() or 'v1'}")
 
 
 @app.get("/")
