@@ -89,7 +89,7 @@ def delete_endpoint(*, lambda_name: str, path: Path):
 
 def parse_api_verb_definition(*, name: str, swagger_definition: Dict):
     _api_verbs = json.dumps(swagger_definition)
-    _api_verbs = _api_verbs.replace('{{lambdaName}}', name)
+    _api_verbs = _api_verbs.replace('{{lambdaName}}', name.replace('-', ' ').replace("_", " ").title().replace(" ", ""))
     return json.loads(_api_verbs)
 
 
@@ -168,8 +168,9 @@ def parse_lambda_cfn_configuration(*, handler: str, name: str, path: Path):
     cfn_lambda = json.loads(path_lambda_configuration.read_text())
     cfn_lambda['Properties']['FunctionName']["Fn::Sub"] = cfn_lambda['Properties']['FunctionName']["Fn::Sub"].replace(
         "{{name}}", name)
-    cfn_lambda['Properties']['Code'] = path.__str__().replace(os.sep, '/')
-    cfn_lambda['Properties']['Handler'] = handler
+    cfn_lambda['Properties']['Code'] = cfn_lambda['Properties']['Code'].replace("{{code}}",
+                                                                                path.__str__().replace(os.sep, '/'))
+    cfn_lambda['Properties']['Handler'] = cfn_lambda['Properties']['Handler'].replace("{{handler}}", handler)
     return cfn_lambda
 
 
@@ -201,6 +202,8 @@ def validate_if_exist_verb_in_endpoint(verb: Verbs, endpoint: str):
     from aoricaan_cli.src.lambdas import work_path
     endpoints = {}
     for lmd in os.listdir(work_path):
+        if not work_path.joinpath(lmd).is_dir() or (not work_path.joinpath(lmd).joinpath(configuration_name).exists()):
+            continue
         config = json.loads(work_path.joinpath(lmd).joinpath(configuration_name).read_text())
         swagger = config['swagger']
         original_endpoint = list(swagger)[0] if swagger else None
