@@ -8,7 +8,7 @@ class Verbs(str, Enum):
     GET = 'get'
     PUT = 'put'
     POST = 'post'
-    PATCH = 'path'
+    PATCH = 'patch'
     DELETE = 'delete'
 
 
