@@ -47,6 +47,8 @@ def build_layers(*, layers_path: Path, bucket=None, use_zip=False):
 
     for layer in tqdm.tqdm(os.listdir(layers_path)):
         layer_path = layers_path.joinpath(layer)
+        if not layer_path.is_dir():
+            continue
 
         layer_path = layer_path.joinpath('python')
         try:
@@ -65,9 +67,12 @@ def build_all_lambdas(*, lambdas_path: Path, path_cfn_template: Path, path_swagg
     for path in os.listdir(lambdas_path):
         name = path
         path = lambdas_path.joinpath(path)
-        if (path == lambdas_path) or not (os.path.isdir(path)):
+        if (path == lambdas_path) or not path.is_dir():
             continue
 
+        name = name.replace('-', ' ').replace("_", " ").title().replace(" ", "")
+        if not path.joinpath('configuration.json').exists():
+            continue
         configuration = json.loads(path.joinpath('configuration.json').read_text())
         cfn_template['Resources'][name] = configuration['cfn']
         for k, v in configuration['swagger'].items():
